# Privacy-Fighter
Easy to setup, fully transparent, online privacy protection solution.
A resource you can point your friends and family to, when explaining why online privacy matters or
if they believe we can't do anything about it.

Online Privacy, The issue:
benjmin quote:  yet here we are in a society where "terms and conditions" are deliberately made lengthy and cognitively uneasy to read and we unknowingly accept them. Companies, who's business model is to sell privacy are among the biggest enterprises.
There are large number of data brokers who's sole business is to profile/catagorise people. whose names you'd have not heard the of.

Confirmation Bias (The bubble):
Inherent in humans.
youtube videos, recommendations

For the most part, the state of the world is what Google results show. And results are different for everyone. Decided by machine learning algorithms


The fight we need to fight
Sounds like paranoia? Check yourself:


Methods of tracking

Cookies:
URL perameters:

fingerprint2js
penopicle


The solution:
Usually people say we don't have any choice, we have already lost. But we do! there are brilliant, hard working people who spend
countless hours to make these anti tracking tools. This project is just a collection and setup of the best tools I have found.
NOTICE: These tools cannot prevent (only partially) tracking done by websites that you are logged into. For example, if you are logged into google account and watching youtube videos, that activity is linked to your account.

Security Improvements:
Online ad networks are known to spread malware (malicious software: viruses, etc) [https://en.wikipedia.org/w/index.php?title=Ad_blocking&section=5#Security]. Effective Adbloking alone is a huge
security improvement. Many other security benifits included. HttpsEveryware: , CookieAutoDelete,

Improve Speed and Save Bandwidth:

Goals:
researching and collecting the best anti tracking tools.
Install and configure them to minimise breaking of sites while retaining good privacy level.
Create a simple Installation method so non technical people can easily install and use it.

Tools used.

This project focuses on researching about the available privacy tools, evaluating, configuring, testing and packaging them. doesn't create anything new.

## Requirements
firefox >=60

Why Firefox?

Chrome and firefox. even chromium has tracking deep builtin.
Firefox allows

## Installation
Files to copy from older profile.

places.sqlite             # Bookmarks, Downloads and Browsing History

logins.json               # encrypted usernames/passwords
key4.db                   # file needed to decrypt users/pass's
formhistory.sqlite        # forms

Simplest option is to install with pip using sudo.
``` bash
sudo python3 -m pip install pillowcover --upgrade
```
#TODO: As a user I would like to ... so that ...
https://gist.github.com/kaefer3000/73febe1eec898cd50ce4de1af79a332a 		python script to decompress mozlz4 file
./mozlz4a.py -d ./search.json.mozlz4 search.json
git diff -U0 --word-diff --no-index -- search-ddg.json search.json

The change is 'current' search engine set to DDG and the hash
`{"current":"DuckDuckGo","hash":"5Hdn3cSCBs7eu4d+SSpLF3BoGMJ8xYlSKYytugKVAy0="}`

KNOWN INCONVENIENCES:
Have to maximise window
temp containers can't go back when container changes.

## Usage


``` bash

```

## Usage Options

#TODO: test url cleaner with temp containers, using ZAP  
